"use strict";

exports.anyOf = anyOf;
exports.charClass = charClass;
exports.charRange = charRange;
exports.inverted = void 0;
exports.negated = negated;
var _encoder = require("../encoder.js");
function charClass(...elements) {
  if (!elements.length) {
    throw new Error('`charClass` should receive at least one element');
  }
  return {
    chars: elements.map(c => c.chars).flat(),
    ranges: elements.map(c => c.ranges ?? []).flat()
  };
}
function charRange(start, end) {
  if (start.length !== 1) {
    throw new Error('`charRange` should receive only single character `start` string');
  }
  if (end.length !== 1) {
    throw new Error('`charRange` should receive only single character `end` string');
  }
  if (start > end) {
    throw new Error('`start` should be before or equal to `end`');
  }
  return {
    chars: [],
    ranges: [{
      start,
      end
    }]
  };
}
function anyOf(characters) {
  const chars = characters.split('').map(c => escapeForCharacterClass(c));
  if (chars.length === 0) {
    throw new Error('`anyOf` should received at least one character');
  }
  return {
    chars
  };
}
function negated(element) {
  return (0, _encoder.encodeCharClass)(element, true);
}
const inverted = exports.inverted = negated;
function escapeForCharacterClass(text) {
  return text.replace(/[\]\\]/g, '\\$&');
}
//# sourceMappingURL=char-class.js.map