import { encodeCharClass } from "../encoder.mjs";
export function charClass(...elements) {
  if (!elements.length) {
    throw new Error('`charClass` should receive at least one element');
  }
  return {
    chars: elements.map(c => c.chars).flat(),
    ranges: elements.map(c => c.ranges ?? []).flat()
  };
}
export function charRange(start, end) {
  if (start.length !== 1) {
    throw new Error('`charRange` should receive only single character `start` string');
  }
  if (end.length !== 1) {
    throw new Error('`charRange` should receive only single character `end` string');
  }
  if (start > end) {
    throw new Error('`start` should be before or equal to `end`');
  }
  return {
    chars: [],
    ranges: [{
      start,
      end
    }]
  };
}
export function anyOf(characters) {
  const chars = characters.split('').map(c => escapeForCharacterClass(c));
  if (chars.length === 0) {
    throw new Error('`anyOf` should received at least one character');
  }
  return {
    chars
  };
}
export function negated(element) {
  return encodeCharClass(element, true);
}
export const inverted = negated;
function escapeForCharacterClass(text) {
  return text.replace(/[\]\\]/g, '\\$&');
}
//# sourceMappingURL=char-class.mjs.map